package Local::ImportModule;
use strict;
use warnings;

use Debug::Helper::Flag qw(DEBUG_FLAG);



1;



__END__


=pod


=head1 NAME

Local::ImportModule - Dummy for testing puposes.


=head1 SYNOPSIS

   use Local::Preparetest;
   use Debug::Helper::Flag DEBUG_FLAG => 0;

   use Local::ImportModule;

=head1 DESCRIPTION

This module does nothing but simply load the L<Debug::Helper::Flag> module. Only
for testing puposes.


=head1 COPYRIGHT

    Copyright 2023 Elektrobit Automotive GmbH
    All rights exclusively reserved for Elektrobit Automotive GmbH,
    unless expressly agreed to otherwise.


=head1 SEE ALSO


L<Debug::Helper::Flag>,
L<Local::Preparetest>

=cut
